@@ -61,6 +61,7 @@ CREATE TABLE ofRoster (
   ask                   INTEGER         NOT NULL,
   recv                  INTEGER         NOT NULL,
   nick                  NVARCHAR(255),
+  stanza                NTEXT,
   CONSTRAINT ofRoster_pk PRIMARY KEY (rosterID)
 );
 CREATE INDEX ofRoster_username_idx ON ofRoster (username ASC);
@@ -214,6 +215,10 @@ CREATE TABLE ofMucRoom (
   canChangeNick       INT           NOT NULL,
   canRegister         INT           NOT NULL,
   allowpm             INT           NULL,
+  fmucEnabled         INT           NULL,
+  fmucOutboundNode    NVARCHAR(255) NULL,
+  fmucOutboundMode    INT           NULL,
+  fmucInboundNodes    NVARCHAR(2000) NULL,
   CONSTRAINT ofMucRoom_pk PRIMARY KEY (serviceID, name)
 );
 CREATE INDEX ofMucRoom_roomid_idx on ofMucRoom(roomID);
@@ -375,7 +380,7 @@ INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
 INSERT INTO ofID (idType, id) VALUES (27, 1);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 30);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 33);
 
 /* Entry for admin user */
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
